#!/bin/bash

BASE=$(pwd)
CODELAB=$(cd ../../; pwd)
JAVAHOME=$CODELAB/mac-app/Contents/Java/jdk-17.0.8.1+1/Contents/Home
CLASSNAME=$(basename "$BASE")
CLASSNAME_LOWER=$(echo "$CLASSNAME" | tr '[:upper:]' '[:lower:]')
PACKAGE=codelab/modules/$CLASSNAME_LOWER
CLS="printf \33c\e[3J"

JAR=$JAVAHOME/bin/jar
JAVA=$JAVAHOME/bin/java
JAVAC=$JAVAHOME/bin/javac
CLASSPATH=class:lib/*

#########################################################
# Displaying some information
#########################################################

$CLS
echo ---------------------------------------------------
echo "CLASSNAME=$CLASSNAME"
echo "PACKAGE=$PACKAGE"
echo "BASE=$BASE"
echo "JAVAHOME=$JAVAHOME"
echo ---------------------------------------------------

#########################################################
# Compiling the Java files
#########################################################

echo "Compiling the Java files..."

rm -rf class/*
set -e
$JAVAC -encoding UTF8 \
	-classpath $CLASSPATH \
	-sourcepath src \
	-d class \
	src/$PACKAGE/*.java

#########################################################
# Generating the libraries
#########################################################

echo "Generating the libraries..."

cd includes
for fname in *.xml; do
	[ -f "$fname" ] || continue
	echo "   $fname"
	$JAVA -jar ../lib/codelab.jar Parser $fname
done

#########################################################
# Packaging the module
#########################################################

echo "Packaging the module..."

cd ..
cp -r data class
cp -r includes class
cp -r templates class
cp -r exercices class
find class -name *.DS_Store -delete

cd class
for fname in ../lib/*.jar; do
	[ -f "$fname" ] || continue
	$JAR -xf $fname
done

rm -rf META-INF
$JAR cf $CLASSNAME.pac $PACKAGE *
mv $CLASSNAME.pac $CODELAB/plugins

#########################################################
# That's All Folks
#########################################################
